@@ -172,6 +172,10 @@ class RecordLoader:
     #         recordChannel.Channel = channel
     #         record.recordChannels.append(recordChannel)
     #     return record
+    
+    def getMetaData(self, recordId):
+        self.logError("getMetadata not implemented in used recordloader")
+        return {}
 
     def getSignalTypeStrFromDict(self, signalName):
         if self.signalTypeDict == {}:
@@ -183,7 +187,21 @@ class RecordLoader:
             signalTypeStr = "unknown"
         return signalTypeStr
 
-    def groupBy(self, group, recordIds):
-        if group is not None:
-            raise Exception("groupBy is not implemented by this RecordLoader, can't group by '%s'" % group)
-        return {recordId: [recordId] for recordId in recordIds}
+    def groupBy(self, groupName, recordIds, metadata=None):
+        if groupName is not None and metadata is None:
+            raise Exception("groupBy is not implemented by this RecordLoader, can't group by '%s'" % groupName)
+        if groupName is None:
+            return {recordId: recordId for recordId in recordIds}
+        
+        # group by metadata list
+        recordGroups = {}
+        for data in metadata:
+            recordGroups[data["recordId"]] = data[groupName] if groupName in data else ""
+        
+        groupedIds = {}
+        for r in recordIds:
+            group = recordGroups[r] if r in recordGroups else ""
+            if group not in groupedIds:
+                groupedIds[group] = []
+            groupedIds[group].append(r)
+        return groupedIds
