@@ -131,8 +131,12 @@ class RecordSignal:
         return signal
 
     def getSignalIndexByName(self, name):
-        if name not in self.signalNames and name == "FLATLINE":
-            self.generateFlatline()
+        if name not in self.signalNames:
+            if name == "FLATLINE":
+                self.generateFlatline()
+            else:
+                from .RecordLoader import ChannelsNotPresent
+                raise ChannelsNotPresent([name])
         return self.signalNames.index(name)
 
     def getSignalByName(self, name) -> Signal:
